Range-v3: ranges::v3::meta::quote< C > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Instances and minimal complete definitions | Public Types | List of all members
ranges::v3::meta::quote< C > Struct Template Reference

## Description

### template<template< typename...> class C>
struct ranges::v3::meta::quote< C >

Turn a class template or alias template `C` into a Metafunction Class.

## Public Types
template<typename... Ts>
using | apply = eval< impl< list< Ts...>>>